<?php

namespace Ems\Controllers;

use Ems\Services\ParamOrgService;
use Ems\Util\ExpectedException;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class ParamOrgController {
    /** @var ParamOrgService */
    protected $paramOrgService;

    public function __construct(
        ParamOrgService $paramOrgService
    ) {
        $this->paramOrgService = $paramOrgService;
    }

    public function getValorReferencia(
        DTO\Request\Row $request,
        DTO\Response $response
    ) {
        try {
            $row = $request->getRow();

            $dsReferencia = (string) $row['DSREFERENCIA'];

            $valorReferencia = $this->paramOrgService->getValorReferencia(
                $dsReferencia
            );

            $valor = $valorReferencia ?
                $valorReferencia['VRREFERENCIA'] :
                null;

            $dataSet = [
                'valor' => $valor,
            ];

            $response->addDataSet(new DataSet('getValorReferencia', $dataSet));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}